@@ -9,7 +9,7 @@ if sys.version_info[:2] < (3, 6):
     collect_ignore.append("async_fixtures/test_nested_36.py")
 
 
-@pytest.yield_fixture()
+@pytest.fixture
 def dependent_fixture(event_loop):
     """A fixture dependent on the event_loop fixture, doing some cleanup."""
     counter = 0
@@ -17,7 +17,7 @@ def dependent_fixture(event_loop):
     async def just_a_sleep():
         """Just sleep a little while."""
         nonlocal event_loop
-        await asyncio.sleep(0.1, loop=event_loop)
+        await asyncio.sleep(0.1)
         nonlocal counter
         counter += 1
 
