@@ -1,12 +1,19 @@
 """Tests for the Hypothesis integration, which wraps async functions in a
 sync shim for Hypothesis.
 """
+import asyncio
 
 import pytest
 
 from hypothesis import given, strategies as st
 
 
+@pytest.fixture(scope="module")
+def event_loop():
+    loop = asyncio.get_event_loop()
+    yield loop
+
+
 @given(st.integers())
 @pytest.mark.asyncio
 async def test_mark_inner(n):
@@ -25,3 +32,11 @@ async def test_mark_outer(n):
 async def test_mark_and_parametrize(x, y):
     assert x is None
     assert y in (1, 2)
+
+
+@given(st.integers())
+@pytest.mark.asyncio
+async def test_can_use_fixture_provided_event_loop(event_loop, n):
+    semaphore = asyncio.Semaphore(value=0)
+    event_loop.call_soon(semaphore.release)
+    await semaphore.acquire()
